@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Play the tabla!
 
-our $VERSION = '0.0103';
+our $VERSION = '0.0104';
 
 use lib map { "$ENV{HOME}/sandbox/$_/lib" } qw(MIDI-Util MIDI-Drummer-Tiny);
 
@@ -192,7 +192,7 @@ Music::Percussion::Tabla - Play the tabla!
 
 =head1 VERSION
 
-version 0.0103
+version 0.0104
 
 =head1 SYNOPSIS
 
@@ -202,6 +202,21 @@ version 0.0103
 
   say $tabla->soundfont;
 
+  for my $i (1 .. 3) {
+      $tabla->ta;
+      $tabla->ta;
+      $tabla->tun;
+      $tabla->ga;
+      $tabla->rest($tabla->quarter);
+  }
+  $tabla->rest($tabla->whole);
+
+  $tabla->timidity_conf('/tmp/timidity.cfg'); # save the cfg
+  $tabla->write; # save the score as a MIDI file
+
+  # OR:
+  $tabla->play_timidity; # play the MIDI with timidity
+
 =head1 DESCRIPTION
 
 C<Music::Percussion::Tabla> provides named associations between tabla
